#!/opt/cycle/jetpack/system/embedded/bin/python

import os
import sys
import os.path
import platform
import subprocess


def is_windows():
    return 'windows' in platform.system().lower()

cyclecloud_home = os.environ.get('CYCLECLOUD_HOME',
                                  'c:\\cycle\\jetpack' if is_windows() else
                                  '/opt/cycle/jetpack').strip('\\')

JETPACK_CMD = os.path.join(cyclecloud_home, 'bin', 'jetpack')
SUCCESS_FILE = os.path.join(cyclecloud_home, "system", "run", "keepalive")
DEFAULT_TIMEOUT = 14400


def uptime():
    if not sys.platform.startswith('win'):
        raise RuntimeError("This function is to be used in windows only")
    try:
        import wmi
    except:
        raise RuntimeError("wmi is not installed!")
    
    c = wmi.WMI()
    perf = c.Win32_PerfFormattedData_PerfOS_System()
    seconds = perf[0].SystemUpTime
    return int(seconds)

def keepalive():
    """Check if this node has converged (and should now stay up)."""
    if os.path.isfile(SUCCESS_FILE):
        print("Staying alive : %s exists." % SUCCESS_FILE)
        return 0

    if is_windows():
        upseconds = uptime()
    else:
        if os.path.isfile('/proc/uptime'):
            f = open('/proc/uptime')
            upseconds = int((f.readline().split('.')[0]))
            f.close()
        else:
            print("Cannot determine uptime. Staying alive.", file=sys.stderr)
            exit(0)

    cmd = JETPACK_CMD + ' config cyclecloud.keepalive.timeout'
    try:
        output = subprocess.check_output(cmd, shell=True)
        timeout = int(output.strip())
    except:
        timeout = DEFAULT_TIMEOUT

    if upseconds > timeout:
        print("Software configuration failed after %s seconds (retry timeout exceeded)" % upseconds, file=sys.stderr)
        return 254

    print("Waiting for keepalive marker. Uptime: %s seconds of %s allowed." % (upseconds, timeout))
    return 0


if __name__ == '__main__':
    try:
        retcode = keepalive()
        sys.exit(retcode)
    except SystemExit:
        sys.exit(retcode)
    except:
        sys.exit(0)  # Exit status 0 on exception, bad code shoudln't kill the node
