
_die () { echo 'Error: ' $* ; exit 1; }
_usage () { echo 'Usage: ' $* ; exit 1; }

ids () { condor_q -format '%s\n' ClusterId; }

machine () {
  test -n "$1" || _usage 'machine <clusterid>'
  condor_q -long "$1" | grep RemoteHost | awk '{print $3}' | sed 's!\"!!g'
}

slots () { condor_status -format '%s\n' Machine; }
machines () { condor_status -format '%s\n' Machine | uniq; }

shutdown_status () { 
  if [ -n "$1" ]; then 
    condor_status -format '%s\n' 'ifThenElse(isUndefined(CycleCloud_shutdown_status), "Persistent", CycleCloud_shutdown_status)' $1 | head -1 | sed 's! of .*!!' | sed 's!Still have!Shutdown in!'
  fi
}

public_hostname () { 
  if [ -n "$1" ]; then 
    ssh $1 curl -s http://169.254.169.254/latest/meta-data/public-hostname 2>&-
  else
    curl -s http://169.254.169.254/latest/meta-data/public-hostname 2>&-
  fi
}

machine_type () { 
  if [ -n "$1" ]; then 
    __type=`ssh $1 curl -s http://169.254.169.254/latest/meta-data/instance-type 2>&-`
  else
    __type=`curl -s http://169.254.169.254/latest/meta-data/instance-type 2>&-`
  fi
  case $__type in 
     m1.small) echo 'standard 1x';;
     m1.large) echo 'large 2x   ';;
    m1.xlarge) echo 'xlarge 4x  ';;
    c1.medium) echo 'high-cpu 2x';;
    c1.xlarge) echo 'high-cpu 8x';;
        cc1.1) echo 'hpc 8x     ';;
            *) echo $__type;;
  esac
  unset __type
}

machine_info () {
  _inthost=`hostname | sed 's!\.ec2.*!!'`
  _pubhost=`public_hostname $_inthost`
  _type=`machine_type $_inthost`
  _status='Scheduler'
  printf "%-45s %-45s %-15s %-10s\n" "$_inthost" "$_pubhost" "$_type" "$_status"
  for _inthost in `machines`; do
    _inthost=`echo $_inthost | sed 's!\.ec2.*!!'`
    _pubhost=`public_hostname $_inthost`
    _type=`machine_type $_inthost`
    _status=`shutdown_status $_inthost`
    printf "%-45s %-45s %-15s %-10s\n" "$_inthost" "$_pubhost" "$_type" "$_status"
  done
  unset _inthost _pubhost _type __status
}

dsh () {
  for m in `machines`; do
    _result=`ssh $m "$@" 2> /dev/null`
    echo $m: $_result
  done
}

distribute () {
  test -n "$1" || _usage 'distribute <file>'
  test -f "$1" || _die "file not found: '$1'"
  for m in `machines`; do
     scp "$1" $m:
     if [ "$1" = cycle-state.tar ]; then
       ssh $m tar xf cycle-state.tar
     fi
  done
}

epoch_to_date () { date  +'%F %T' -d @$1; }

running () {
  condor_q -constraint JobStatus==2 -format '%4s ' ClusterId -format '%8s  ' Owner -format '%s\n' RemoteHost
}

idle () {
  condor_q -constraint JobStatus==1 -format '%4s ' ClusterId -format '%8s  \n' Owner
}

completed () {
  condor_q -constraint JobStatus==4 -format '%4s ' ClusterId -format '%8s  ' Owner -format '%d  ' ExitCode -format '%s\n' LastRemoteHost
}

failed () {
  condor_q -constraint JobStatus==4 -constraint ExitCode!=0 -format '%4s ' ClusterId -format '%8s  ' Owner -format '%d  ' ExitCode -format '%s\n' LastRemoteHost
}

held () {
  condor_q -constraint JobStatus==3 -format '%4s ' ClusterId -format '%8s  ' Owner -format '%s\n' LastRemoteHost
}

state () {
  test -n "$1" || _usage 'state <clusterid>'
  _state=`condor_q -long "$1" | grep JobStatus | awk '{print $3}'`

}
