condor_version = node['htcondor']['version']

if node['os'] == "windows"
  condor_agent_package_name = "condor-agent-#{node['htcondor']['agent_version']}.zip"
else
  condor_agent_package_name = "condor-agent-#{node['htcondor']['agent_version']}.tgz"
end

jetpack_download condor_agent_package_name do
  project 'htcondor'
end

if node['os'] == "windows"

  agent_dir = "c:\\windows\\temp\\condor-installer\\agent"
  directory agent_dir

  powershell_script 'unpackagent' do
    code <<-EOH
      Add-Type -assembly "system.io.compression.filesystem"
      [io.compression.zipfile]::ExtractToDirectory(
        "#{node['jetpack']['downloads']}/#{condor_agent_package_name}",
        "#{agent_dir}"
      )
    EOH
    creates "#{agent_dir}\\install.bat"
  end

  # Not sure why there are multiple archive levels here.
  # This is a bit of insanity.
  condor_bin_path = "C:\\condor\\bin"
  condor_agent_file = "#{agent_dir}\\condor_agent-#{node['htcondor']['agent_version']}-win32.zip"

  powershell_script 'condor agent install' do
    code <<-EOH
      Add-Type -assembly "system.io.compression.filesystem"
      [io.compression.zipfile]::ExtractToDirectory(
        "#{condor_agent_file}",
        "#{condor_bin_path}"
      )
    EOH
    creates "#{condor_bin_path}\\condor_agent\\condor_agent.exe"
  end

else
  tmp_install_dir = "/tmp/condor-#{condor_version}-installer/agent"

  directory tmp_install_dir do
      owner "condor"
      group "condor"
      mode "0755"
      recursive true
  end

  execute "unpackagent" do
    command "tar -xzf #{node['jetpack']['downloads']}/#{condor_agent_package_name} -C #{tmp_install_dir}"
    creates "#{tmp_install_dir}/install.sh"
    action :run
  end

  # There is an install.sh we 'could' use, but it just calls the ruby file
  # This way we can call the ruby directly using the appropriate environment
  execute 'condor agent install' do
    command "#{node['cyclecloud']['bootstrap']}/cron_wrapper.sh ruby install.rb"
    cwd tmp_install_dir
    creates '/opt/condor/agent'
  end

end
