# Cookbook Name:: ccondor
# Recipe:: poolpass
#

chefstate = node[:cyclecloud][:chefstate]
cuser = node[:cyclecloud][:cluster][:user][:name]
cpass = node[:cyclecloud][:cluster][:user][:password]
chost = node[:hostname]

if node[:cyclecloud][:cluster][:parent_id].nil?
  mykey=node[:htcondor][:pool_password]
else
  parent_node = cluster.search(:clusterUID=>node[:cyclecloud][:cluster][:parent_id]).first
  if parent_node
    mykey = parent_node[:htcondor][:pool_password]
  else
    raise "Unable to find parent cluster node - likely a timing issue, next converge should fix it."
  end
end

if node[:os] == "windows"
    execute "C:\\Condor\\bin\\condor_store_cred add -u #{cuser}@#{chost} -p #{cpass}"
    execute "C:\\Condor\\bin\\condor_store_cred add -c -p #{mykey}"
else
  execute "rootpoolpass" do
    command "test -f /mnt/condor_data/condor_config.cloud && . /etc/profile.d/condor.sh && /opt/condor/current/sbin/condor_store_cred add -c -f /root/.pool -p \"#{mykey}\" && chmod 0400 /root/.pool && touch #{chefstate}/ccondor.rootpoolpass.done"
    not_if "test -f #{chefstate}/ccondor.rootpoolpass.done"
    action :run
  end

  execute "symlinkpoolpass" do
    command "test -f /root/.pool && ln -sf /root/.pool /.pool && touch #{chefstate}/ccondor.symlinkpoolpass.done"
    not_if "test -f #{chefstate}/ccondor.symlinkpoolpass.done"
    action :run
  end

  # case 11110: create password file just for daemons to read which is owned by root
  execute "daemonpoolpass" do
    command "test -f /root/.pool && cp /root/.pool /mnt/condor_data/.pool && touch #{chefstate}/ccondor.daemonpoolpass.done"
    not_if "test -f #{chefstate}/ccondor.daemonpoolpass.done"
    action :run
  end

  # create the pool password for common users
  %w{cyclecloud condor}.each do | usr |
    execute "#{usr} pool pass" do
      command "test -f /root/.pool && cp -f /root/.pool ~#{usr}/.pool && chmod 0400 ~#{usr}/.pool && chown #{usr}:#{usr} ~#{usr}/.pool && touch #{chefstate}/#{usr}.poolpass.done"
      not_if "test -f #{chefstate}/#{usr}.poolpass.done"
      only_if "test -d ~#{usr}"
      action :run
    end
  end

  include_recipe 'ccondor::_poolpass_user_homes'

  # execute "#{cyclecloud_user_name} pool pass" do
  #   command "test -f /root/.pool && cp -f /root/.pool ~#{cyclecloud_user_name}/.pool && chmod 0400 ~#{cyclecloud_user_name}/.pool && chown #{cyclecloud_user_name}:#{cyclecloud_user_name} ~#{cyclecloud_user_name}/.pool && touch #{chefstate}/ccondor.#{cyclecloud_user_name}.poolpass.done"
  #   not_if "test -f #{chefstate}/#{cyclecloud_user_name}.poolpass.done"
  #   only_if "test -d ~#{cyclecloud_user_name}/"
  #   action :run
  # end

  execute "execpoolpass" do
    command "test -f /root/.pool && cp -f /root/.pool /mnt/condor_data/lock/PoolPassword && chown condor:condor /mnt/condor_data/lock/PoolPassword && chmod 0400 /mnt/condor_data/lock/PoolPassword && touch #{chefstate}/ccondor.execpoolpass.done"
    not_if "test -f #{chefstate}/condor.execpoolpass.done"
    action :run
  end


  directory "/etc/skel" do
    if not node[:os] == "windows"
      owner "root"
      group "root"
      mode "0755"
    end
    action :create
    recursive true
  end

  execute "skel pool pass" do
    command "test -f /root/.pool && cp -f /root/.pool /etc/skel/.pool"
    not_if "test -f /etc/skel/.pool"
    action :run
  end

end
