#
# Cookbook Name:: ccondor
# Recipe:: scheduler
#
# Copyright 2017, Cycle Computing
#
# All rights reserved - Do Not Redistribute
#

include_recipe "ccondor::default"
include_recipe "cyclecloud"

central_manager_internal_hostname = cluster.cm_hostname
scheduler_internal_hostname       = cluster.scheduler

data_dir = node[:htcondor][:data_dir]

# For multiple schedulers...
%w{1 2}.each do |n|
  directory "#{data_dir}/spool/#{n}" do
    if not node[:os] == "windows"
      owner "condor"
      group "condor"
      mode "0755"
    else
      rights :full_control, "Everyone"
    end
  end
end

# This is needed to make the multi-schedd stuff work. The Shadows
# have a bug in them in the 7.6.x series that prevents them from
# seeing the Schedd-specific SPOOL variable. This gets around it.
# For non-multi-schedd setups it's essentially a null-op since the
# file is overwritten by Condor when the condor_schedd is started
# on the box.
template "#{data_dir}/spool/spool_version" do
  source "spool_version.schedd.erb"
  if not node[:os] == "windows"
    mode "0644"
    owner "condor"
    group "condor"
  else
    rights :full_control, "Everyone"
  end
end

# This directory is used by the Condor Agent for REST-based local
# submissions to the schedulers on the machine.
directory "#{data_dir}/submit" do
  if not node[:os] == "windows"
    owner "condor"
    group "condor"
    mode "0777"
  else
    rights :full_control, "Everyone"
  end
end


if central_manager_internal_hostname == nil
  Chef::Log.info "CM unknown. Aborting converge."
  exit 1
else
  Chef::Log.info "CM: #{central_manager_internal_hostname}"
  Chef::Log.info "Sched: #{scheduler_internal_hostname}"
  if node[:os] == "windows"

    cookbook_file "C:\\condor\\condor_config" do
      source "win-condor-config-sched"
    end

    # allow everyone read,execute perms to condor_config.local
    execute "icacls c:\\condor\\condor_config /grant Everyone:(RX)"

    # template condor_config.local
    template "#{data_dir}\\condor_config.local" do
      source "win-condor-config-local-sched.erb"
      variables(:central_manager_internal_hostname => central_manager_internal_hostname,
                :scheduler_internal_hostname => scheduler_internal_hostname)
    end

    # allow everyone read,execute perms to condor_config.local
    #execute "icacls #{data_dir}\\condor_config.local /grant Everyone:(RX)"

  else # linux


    cookbook_file "/opt/condor/condor_config.sched" do
      path "/opt/condor/condor_config"
      source "condor_config.sched"
      if not node[:os] == "windows"
        owner "root"
        group "root"
        mode "0644"
      end
    end

    template "Scheduler: /opt/condor/local_config.sh" do
      path "/opt/condor/local_config.sh"
      source "local_config_sched.sh.erb"
      if not node[:os] == "windows"
        mode "0644"
        owner "root"
        group "root"
      end
      variables(:central_manager_internal_hostname => central_manager_internal_hostname)
    end

    template "Scheduler: /mnt/condor_data/condor_config.cloud" do
      path "/mnt/condor_data/condor_config.cloud"
      source "condor-config-local-sched.erb"
      if not node[:os] == "windows"
        mode "0644"
        owner "root"
        group "root"
      end
      variables(:central_manager_internal_hostname => central_manager_internal_hostname)


      notifies :run, "execute[condor-reconfig]"

    end

    template "/etc/cron.hourly/shadow_log_remove.sh" do
      source "shadow_log_remove.sh.erb"
      if not node[:os] == "windows"
        mode "0744"
        owner "root"
        group "root"
      end
    end


  end
end

include_recipe "ccondor::poolpass"

# Defer service start until end of converge so that all configuration is completed
# (including cluster-inits)
if node[:os] == "windows"

  # only restart condor the first time around
  restart_file = "#{node[:cyclecloud][:bootstrap]}\\condor_restarted"

  execute "touch_condor_restarted" do
    command "copy nul #{restart_file}"
    creates restart_file
    action :nothing
  end
  
  execute "net_start_condor" do
    command "net start condor"
    returns [0,2]
    notifies :run, 'execute[touch_condor_restarted]', :immediately
    action :nothing
  end

  defer_block 'Defer start of windows Condor scheduler node until end of converge' do
    execute "net stop condor" do
      returns [0,2] # ignore error trying to stop condor when its not running
      notifies :run, 'execute[net_start_condor]', :immediately
      not_if do FileTest.exist? restart_file end
    end
  end

  
  

else #linux

  defer_block 'Defer start of linux Condor scheduler node until end of converge' do
    service "condor" do
      supports :status => true, :restart => true
      action [ :enable, :start ]
    end
  end
  
end


