#
# Cookbook Name:: nfs
# Recipe:: server
#

glusterthreads="64"

package "glusterfs-server" do
  action :install
end

package "glusterfs-client" do
  action :install
end

template "/etc/glusterfs/glusterfsd.vol" do
  source "glusterfsd.vol.erb"
  variables({
    :glusterthreads => glusterthreads
  })
end

directory "/mnt/exports" do
  owner "root"
  group "root"
  mode "0755"
  action :create
  only_if "test -d /mnt"
end

directory "/mnt/exports/shared" do
  owner "root"
  group "root"
  mode "0755"
  action :create
  only_if "test -d /mnt/exports"
end

directory "/mnt/exports/sched" do
  owner "root"
  group "root"
  mode "0755"
  action :create
  only_if "test -d /mnt/exports"
end

service "glusterfsd" do
  supports :restart => true
  action [ :enable, :start ]
  only_if "test -d /mnt/exports/shared"
end

directory "/shared" do
  owner "root"
  group "root"
  mode "0755"
  action :create
end

directory "/sched" do
  owner "root"
  group "root"
  mode "0755"
  action :create
end

template "/etc/glusterfs/glusterfs.shared.vol" do
  source "glusterfs.shared.erb"
  variables({
    :glusterd1 => "127.0.0.1"
  })
end
mount "/shared" do
  device "/etc/glusterfs/glusterfs.shared.vol"
  fstype "glusterfs"
  options "defaults"
  action [:mount, :enable]
end

template "/etc/glusterfs/glusterfs.sched.vol" do
source "glusterfs.sched.erb"
  variables({
    :glusterd1 => "127.0.0.1"
  })
end
mount "/sched" do
  device "/etc/glusterfs/glusterfs.sched.vol"
  fstype "glusterfs"
  options "defaults"
  action [:mount, :enable]
end

directory "/shared/home" do
  owner "root"
  group "root"
  mode "0755"
  action :create
  only_if "test -d /shared"
end 

directory "/shared/bin" do
  owner "root"
  group "root"
  mode "1777"
  action :create
  only_if "test -d /shared"
end

directory "/shared/man" do
  owner "root"
  group "root"
  mode "1777"
  action :create
  recursive true
  only_if "test -d /shared"
end

directory "/shared/scratch" do
  owner "root"
  group "root"
  mode "1777"
  action :create
  recursive true
  only_if "test -d /shared"
end

directory "/sched/keys" do
  owner "root"
  group "root"
  mode "0700"
  action :create
  not_if "test -d /sched/keys"
end

execute "generatekeys" do
  command "ssh-keygen -f /sched/keys/mykey -N \"\""
  creates "/sched/keys/mykey"
  action :run
end

