require 'spec_helper'

# Missing things to test:
#  -> NFS - Server is the client, creates links
#  -> Search vs passed in address
#  -> skips disabled mounts?

describe 'cshared::default' do
  context "Mounts a NFS filesystem on LINUX" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(step_into: ['cshared::nfs'], :platform => 'centos', :version => '7.4.1708') do |node|
        node.default['cyclecloud']['mounts']['nfs'] = {
          'type' => 'nfs',
          'export_path' => '/exports/data',
          'address' => '1.2.3.4',
          'mountpoint' => '/data',
          'options' => 'option1,option2'
        }
      end.converge("cshared::default")
    end

    before do
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).and_call_original
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('nfs')

      stub_command("test -d /shared").and_return(false)
      stub_command("test -d /sched").and_return(false)
      stub_command("test -d /data").and_return(false)
    end

    it 'includes the nfs::default recipe' do
      expect_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('nfs')
      chef_run
    end

    it 'creates the nfs directory' do
      expect(chef_run).to create_directory('/data')
    end

    it 'mounts and enables the filesystem' do
      expect(chef_run).to mount_mount('/data').with({
        :device => "1.2.3.4:/exports/data",
        :fstype => "nfs",
        :pass => 0,
        :options => ["option1", "option2"],
        :retries => 5,
        :retry_delay => 30
      })

      expect(chef_run).to enable_mount('/data')
    end
  end

  context "Mounts a NFS filesystem on WINDOWS" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(:platform => 'windows', :version => '2012R2') do |node|
        node.default['cyclecloud']['mounts']['nfs'] = {
          'type' => 'nfs',
          'export_path' => '/exports/data',
          'address' => '1.2.3.4',
          'mountpoint' => '/data',
          'options' => 'option1,option2',
          'windevice' => 'Z'
        }
      end.converge("cshared::default")
    end


    it 'mounts and enables the filesystem' do
      expect(chef_run).to mount_mount('Z:').with({
        :device => '\\\\1.2.3.4\\nfs',
        :retries => 5,
        :retry_delay => 30
      })
    end
  end

  context "Mounts a NFS filesystem on LINUX with multiple IPs" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(step_into: ['cshared::nfs'], :platform => 'centos', :version => '7.4.1708') do |node|
        node.default['cyclecloud']['mounts']['nfs'] = {
          'type' => 'nfs',
          'export_path' => '/exports/data',
          'address' => '1.2.3.4, 1.2.3.4',  # NOTE: Same IP so we sample and find either
          'mountpoint' => '/data',
          'options' => 'option1,option2'
        }
        node.default['cyclecloud']['mounts']['shared']['disabled'] = true
        node.default['cyclecloud']['mounts']['sched']['disabled'] = true
      end.converge("cshared::default")
    end

    before do
      # Stub out the checks to read the iplist from disk
      allow(::FileUtils).to receive(:mkdir_p).and_return(true)
      allow(::File).to receive(:exist?).and_call_original
      allow(::File).to receive(:exist?).with('/opt/cycle/jetpack/config/chefstate/nfs.mount').and_return(false)
      allow(::File).to receive(:open).and_call_original
      allow(::File).to receive(:open).with('/opt/cycle/jetpack/config/chefstate/nfs.mount', 'w').and_return(false)
      

      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).and_call_original
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('nfs')

      stub_command("test -d /data").and_return(false)
    end

    it 'includes the nfs::default recipe' do
      expect_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('nfs')
      chef_run
    end

    it 'creates the nfs directory' do
      expect(chef_run).to create_directory('/data')
    end

    it 'mounts and enables the filesystem' do
      expect(chef_run).to mount_mount('/data').with({
        :device => "1.2.3.4:/exports/data",
        :fstype => "nfs",
        :pass => 0,
        :options => ["option1", "option2"],
        :retries => 5,
        :retry_delay => 30
      })

      expect(chef_run).to enable_mount('/data')
    end
  end
end
