require 'spec_helper'

shared_examples 'directory creation' do |platform, version|
  context "On #{platform} #{version}" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version).converge(described_recipe)
    end

    it 'creates base directories' do
      expect(chef_run).to create_directory("/mnt/exports").with(user: 'root', group: 'root', mode: '0755')
      expect(chef_run).to create_directory("/mnt/exports/shared").with(user: 'root', group: 'root', mode: '0755')
      expect(chef_run).to create_directory("/mnt/exports/sched").with(user: 'root', group: 'root', mode: '0755')
    end

    it 'creates shared subdirs' do
        expect(chef_run).to create_directory("/mnt/exports/shared/bin").with(user: 'root', group: 'root', mode: '0755')
        expect(chef_run).to create_directory("/mnt/exports/shared/man").with(user: 'root', group: 'root', mode: '0755')
        expect(chef_run).to create_directory("/mnt/exports/shared/scratch").with(user: 'root', group: 'root', mode: '0777')
    end

    it 'creates symlinks' do
      expect(chef_run).to create_link("/shared").with(to: "/mnt/exports/shared")
      expect(chef_run).to create_link("/sched").with(to: "/mnt/exports/sched")
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end
end

describe 'cshared::directories' do
  platforms = {
    'centos' => ['6.9', '7.4.1708'],
    'ubuntu' => ['14.04', '16.04']
  }

  platforms.each do |platform,versions|
    versions.each do |version|
      it_behaves_like 'directory creation', platform, version
    end
  end
end
