
action :create do

  crypt_name = new_resource.name
  new_resource.fs_type ||= node[:cyclecloud][:mount_defaults][:fs_type]
  new_resource.key_path ||= "/root/#{crypt_name}.key"
  lv_path = "/dev/mapper/#{new_resource.vg_name}-#{new_resource.lv_name}"

  cvolume_logical_volume "lv for #{new_resource.lv_name} in vg #{new_resource.vg_name}" do
    name new_resource.lv_name
    group new_resource.vg_name
    size new_resource.size
  end

  # If no key is specified, generate a random 2048 byte key
  if new_resource.key.nil?
    execute "makekey" do
      command "/bin/dd if=/dev/urandom of=#{new_resource.key_path} bs=512 count=4 && chmod 400 #{new_resource.key_path}"
      creates new_resource.key_path
    end
  else  # Use the one they specified, it 'should' be big enough but we could validate it
    template new_resource.key_path do
      source "cyclecloud_crypt.erb"
      mode "0400"
      owner "root"
      group "root"
      cookbook 'cvolume'
      variables(:cryptkey => new_resource.key)
    end
  end

  # sometimes this fails but same call will succeed a couple seconds later, thus the retry
  execute "run cryptsetup for #{crypt_name}" do
    command "/sbin/cryptsetup -s #{new_resource.bits} -d #{new_resource.key_path} create #{crypt_name} #{lv_path}"
    not_if "/sbin/cryptsetup status #{crypt_name}"  # Cryptsetup status returns 1 if the device isn't active
    retries 2
    retry_delay 2
  end

  execute "update crypttab for #{crypt_name}" do
    command "echo #{crypt_name} #{lv_path} #{new_resource.key_path} size=#{new_resource.bits},cipher=aes-cbc-plain >> /etc/crypttab"
    not_if "cat /etc/crypttab | grep #{crypt_name}"
  end

  new_resource.updated_by_last_action(true)
end
