# Wipes the default "ext3" filesystem from ephemeral drives that aws provides

return if node[:ec2].nil? or node[:cyclecloud][:instance][:provider] != "ec2"

# Iterate over a possible 99 ephemeral devices to see which ones we have
# We have to iterate over all 99 because it's possible the user only attached 0
# and 30 for example. 99 is a bit excessive, but should be pretty fast.
devices = []
0.upto(99) do |x|
  device = node[:ec2]["block_device_mapping_ephemeral#{x}"]
  if device
    # Sometimes devices dont' have the /dev/ at the start, make sure they do
    unless device.start_with? "/dev/"
      device = "/dev/#{device}"
    end
    devices << device
  end
end

Chef::Log.debug "Found the following ephemeral devices: #{devices}"

# Wipe the filesystem from the ephemeral device if it's ext3 (the default format)
# AND it's never been mounted before. This should be enough info to determine the ephemeral 
# device is a auto format from AWS.
devices.each do |device|
  execute "wipe default filesystem from ephemeral device #{device}" do
    command "wipefs --all #{device}"
    only_if "blkid -o value -s TYPE #{device} | grep ext3"
    only_if "tune2fs -l #{device} | egrep \"Last mount time:\\\\s+n/a\""
  end
end
