#
# Cookbook Name:: cycle_server
# Recipe:: user
#
# Copyright 2014, Cycle Computing, LLC
#
# All rights reserved - Do Not Redistribute
#
# Creates the cycle_server user
#

cshome    = node[:cycle_server][:home]
csuser    = node[:cycle_server][:username]
csgroup   = node[:cycle_server][:group]
csauth_keys     = node[:cycle_server][:authorized_keys] || ""

# Select cycle_server user home directory
if !node[:cycle_server][:home_directory].nil?
  # 1) Allow cycle_server home directory to be set explicitly
  csuser_home = node[:cycle_server][:home_directory]
elsif node[:cuser] && node[:cuser][:base_home_dir]
  # 2) Otherwise, if available, use the common user home directory so that
  #    ~/.ssh is shared (assuming default user home is shared)
  csuser_home = File.join(node[:cuser][:base_home_dir], csuser)
  node.override['cycle_server']['home_directory'] = csuser_home
else
  # 3) Fall back to CS_HOME if cycle_server user home directory not specified
  csuser_home = cshome
  node.override['cycle_server']['home_directory'] = csuser_home
end

# Setup cycle_server user
group csgroup do
  gid node[:cycle_server][:gid]
  not_if "grep -s \"^#{csgroup}:\" /etc/group"
end
user csuser do
  comment "Cycle Server User"
  manage_home true  # auto-create the home dir
  uid node[:cycle_server][:uid]
  gid node[:cycle_server][:gid]
  home csuser_home
  shell "/bin/bash"
  not_if "id -u #{csuser} 2>/dev/null"
end

directory "#{csuser_home}/.ssh" do
  owner csuser
  group csgroup
  mode "0700"
  action :create
  recursive true
end

# careful - could have spaces in it.
schedname = node[:cyclecloud][:cluster][:name].gsub(/\s+/, "_")
bash "keypair" do
 code <<-EOH
  ssh-keygen -f #{csuser_home}/.ssh/id_rsa -N ""
  chmod 600 #{csuser_home}/.ssh/id_rsa
  chown #{csuser}:#{csgroup} #{csuser_home}/.ssh/id_rsa
  chown #{csuser}:#{csgroup} #{csuser_home}/.ssh/id_rsa.pub
  cp #{csuser_home}/.ssh/id_rsa "#{csuser_home}/.ssh/id_rsa_#{schedname}"
  EOH
  creates "#{csuser_home}/.ssh/id_rsa"
end

bash "auth_keys" do
 code <<-EOH
  cat #{csuser_home}/.ssh/id_rsa.pub > #{csuser_home}/.ssh/authorized_keys
  echo "#{csauth_keys}" >> #{csuser_home}/.ssh/authorized_keys
  chmod 0644 #{csuser_home}/.ssh/authorized_keys
  chown #{csuser}:#{csgroup} #{csuser_home}/.ssh/authorized_keys
  EOH
  creates "#{csuser_home}/.ssh/authorized_keys"
end

file "#{csuser_home}/.ssh/config" do
  content 'StrictHostKeyChecking no\n'
  owner csuser
  group csgroup
  mode "0644"
end
