#
# Cookbook Name:: cycle_server
# Spec:: user
#
# Copyright (c) 2016 The Authors, All Rights Reserved.

require 'spec_helper'

shared_examples 'centos-7-user' do
  cached(:chef_run) do
    ChefSpec::SoloRunner.new(platform: 'centos', version: '7.4.1708') do |node|
      node.default['cyclecloud']['cluster']['name'] = 'condor'
      node.default['cyclecloud']['cluster']['user']['name'] = 'cluster.user'
    end.converge(described_recipe)
  end

  it 'creates group cycle_server' do
    expect(chef_run).to create_group('cycle_server')
  end

  it 'creates user cycle_server' do
    expect(chef_run).to create_user('cycle_server')
  end
end

# No platform branching, therefore just test CentOS 7
describe 'cycle_server::user' do
  before do
    stub_command('grep -s "^cycle_server:" /etc/group').and_return(false)
    stub_command('id -u cycle_server 2>/dev/null').and_return(false)

    allow_any_instance_of(Chef::Cookbook::Metadata).to receive(:depends).and_call_original
    allow_any_instance_of(Chef::Cookbook::Metadata).to receive(:depends).with('cuser')
  end

  context 'cuser.base_home_dir is not set' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '7.4.1708') do |node|
        node.default['cyclecloud']['cluster']['name'] = 'condor'
        node.default['cyclecloud']['cluster']['user']['name'] = 'cluster.user'
      end.converge(described_recipe)
    end

    it_behaves_like 'centos-7-user'

    it 'creates directory /mnt/cycle_server/.ssh' do
      expect(chef_run).to create_directory('/mnt/cycle_server/.ssh')
    end

    it 'sets cycle_server.home_directory to /mnt/cycle_server' do
      expect(chef_run.node['cycle_server']['home_directory']).to eq('/mnt/cycle_server')
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end

  context 'cuser.base_home_dir is /shared/home' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '7.4.1708') do |node|
        node.default['cyclecloud']['cluster']['name'] = 'condor'
        node.default['cyclecloud']['cluster']['user']['name'] = 'cluster.user'
        node.default['cuser']['base_home_dir'] = '/shared/home'
      end.converge(described_recipe)
    end

    it_behaves_like 'centos-7-user'

    it 'creates directory /shared/home/cycle_server/.ssh' do
      expect(chef_run).to create_directory('/shared/home/cycle_server/.ssh')
    end

    it 'sets cycle_server.home_directory to /shared/home/cycle_server' do
      expect(chef_run.node['cycle_server']['home_directory']).to eq('/shared/home/cycle_server')
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end

  context 'cycle_server.home_directory is /home/cycle_server' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '7.4.1708') do |node|
        node.default['cyclecloud']['cluster']['name'] = 'condor'
        node.default['cyclecloud']['cluster']['user']['name'] = 'cluster.user'
        node.override['cycle_server']['home_directory'] = '/home/cycle_server'
      end.converge(described_recipe)
    end

    it_behaves_like 'centos-7-user'

    it 'creates directory /shared/home/cycle_server/.ssh' do
      expect(chef_run).to create_directory('/home/cycle_server/.ssh')
    end

    it 'sets cycle_server.home_directory to /shared/home/cycle_server' do
      expect(chef_run.node['cycle_server']['home_directory']).to eq('/home/cycle_server')
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end
end
