default['cyclecloud']['discoverable'] = false

# We install a cron job 'cyclecloud-bootstrap' in Linux that causes Chef to converge immediately after a reboot
# setting this attribute to false will delete that cron job
default['cyclecloud']['converge_on_boot'] = false

# How many minutes in the future should an autostop request be backed up by the
# scheduled_shutdown HealthCheck script?
default['cyclecloud']['autoscale']['forced_shutdown_timeout'] = 15

# (Immutable for reference only)
# The base routing key for service_status messages. The full routing key for a
# service should be:
# "#{node['cyclecloud']['service_status']['routing_key']}.#{service_name}"
default['cyclecloud']['service_status']['routing_key'] = 'cyclecloud.service.status'

# By deafult we do not validation SSL certificates (self signed cause problems
# as well as valid certs via the https tunnel)
default['cyclecloud']['skip_ssl_validation'] = true

default['cyclecloud']['keepalive']['timeout'] = 14_400

# With compatibility mode, we no longer have to worry about 'cyclecloud' home
if node['os'] == 'windows'
  default['cyclecloud']['home'] = 'C:\cycle\jetpack'
  default['cyclecloud']['bootstrap'] = 'C:\cycle\jetpack\system\bootstrap'
  default['cyclecloud']['chefstate'] = 'C:\cycle\jetpack\config\chefstate'
  default['cyclecloud']['converge_index_file'] = 'C:\cycle\jetpack\system\chef\converge_index'
  default['cyclecloud']['failed_converge_file'] = 'C:\cycle\jetpack\system\chef\failed_converge_count'
  default['cyclecloud']['grill_extras_file'] = 'C:\cycle\jetpack\system\chef\grill_extras.json'
else
  default['cyclecloud']['home'] = '/opt/cycle/jetpack'
  default['cyclecloud']['bootstrap'] = '/opt/cycle/jetpack/system/bootstrap'
  default['cyclecloud']['chefstate'] = '/opt/cycle/jetpack/config/chefstate'
  default['cyclecloud']['converge_index_file'] = '/opt/cycle/jetpack/system/chef/converge_index'
  default['cyclecloud']['failed_converge_file'] = '/opt/cycle/jetpack/system/chef/failed_converge_count'
  default['cyclecloud']['grill_extras_file'] = '/opt/cycle/jetpack/system/chef/grill_extras.json'
end

# Set a few defaults that will be passed in by CycleCloud (for spec tests to pass)
default['cyclecloud']['node']['template'] = nil
default['cyclecloud']['node']['placement_group']= nil

# Check for version file
default['cyclecloud']['jetpack']['version_file'] = "#{node['cyclecloud']['home']}/version.txt"

# Read version from file or set to 0
default['cyclecloud']['jetpack']['version'] = begin
                                                IO.read(node['cyclecloud']['jetpack']['version_file']).chomp
                                              rescue
                                                '0.0.0'
                                              end

# startTime - default to the "launchTime" in userdata which is when the API request was made which is inaccurate for spots
default['cyclecloud']['instance']['startTime'] = ::Time.now.to_i

# Flags controlling blackboard search
default['cyclecloud']['search']['caching']['disabled'] = false

default['http_proxy']['url'] = ''

default['cyclecloud']['pogo']['report_metrics'] = false

# This was added for customer(s) that lock down /sbin as read-only
default['cyclecloud']['sbin'] = if ::File.writable?('/sbin')
                                  '/sbin'
                                else
                                  '/usr/local/sbin'
                                end

# Flag for legacy common chef repo
# This is when the cookbooks and packages come from a shared repository instead of staged
# in a local storage locker
default['cyclecloud']['legacy_common_chef_repo'] = true

# this cookbook is deprecated
default['cyclecloud']['thunderball']['config'] = {}
