# This is a conversion for legacy node['ec2']['userdata']['user_data'] attributes
# into an appropriate 'cyclecloud' attribute. This will be replaces ASAP by
# conversion on the iamge side in anticipation of a new userdata format.
return if node['ec2'].nil? || node['ec2']['userdata'].nil?

# RabbitMQ settings - now just generic AMQP settings
if node['ec2']['userdata']['user_data']['rabbitmq']
  default['cyclecloud']['amqp']['hostname'] = node['ec2']['userdata']['user_data']['rabbitmq']['hostname']
  default['cyclecloud']['amqp']['port'] = node['ec2']['userdata']['user_data']['rabbitmq']['port']
  default['cyclecloud']['amqp']['username'] = node['ec2']['userdata']['user_data']['rabbitmq']['user']
  default['cyclecloud']['amqp']['password'] = node['ec2']['userdata']['user_data']['rabbitmq']['password']
  default['cyclecloud']['amqp']['vhost'] = node['ec2']['userdata']['user_data']['rabbitmq']['vhost']
end

# Blackboard search settings
if node['ec2']['userdata']['user_data']['system']['blackboard']
  default['cyclecloud']['blackboard']['type'] = node['ec2']['userdata']['user_data']['system']['blackboard']['scheme']
  default['cyclecloud']['blackboard']['url'] = node['ec2']['userdata']['user_data']['system']['blackboard']['location']
  default['cyclecloud']['blackboard']['access_key'] = node['ec2']['userdata']['user_data']['system']['blackboard']['accessKey']
  default['cyclecloud']['blackboard']['secret_key'] = node['ec2']['userdata']['user_data']['system']['blackboard']['secretKey']
  default['cyclecloud']['blackboard']['detect_credentials'] = node['ec2']['userdata']['user_data']['system']['blackboard']['detectCredentials']
  default['cyclecloud']['blackboard']['default_region'] = node['ec2']['userdata']['user_data']['system']['blackboard']['defaultRegion']
  default['cyclecloud']['blackboard']['username'] = node['ec2']['userdata']['user_data']['system']['blackboard']['username']
  default['cyclecloud']['blackboard']['password'] = node['ec2']['userdata']['user_data']['system']['blackboard']['password']
  # Legacy settings (no type, just bucket and prefix - we may not need to support this)
  unless node['ec2']['userdata']['user_data']['system']['blackboard']['bucket'].nil?
    default['cyclecloud']['blackboard']['type'] = 's3'
    default['cyclecloud']['blackboard']['url'] = "s3://#{node['ec2']['userdata']['user_data']['system']['blackboard']['bucket']}/#{node['ec2']['userdata']['user_data']['system']['blackboard']['prefix']}"
  end
end

# Old pool section
if node['ec2']['userdata']['user_data']['pool']
  default['cyclecloud']['cluster']['name'] = node['ec2']['userdata']['user_data']['pool']['name']
  default['cyclecloud']['cluster']['id'] = node['ec2']['userdata']['user_data']['pool']['uid']
  default['cyclecloud']['cluster']['parent_id'] = node['ec2']['userdata']['user_data']['pool']['parent_uid']

  # Autoscale settings - we dont' ahve to worry about their existence here since cyclecloud always sends them unlike my.cyclecloud.com
  default['cyclecloud']['cluster']['autoscale']['start_enabled'] = node['ec2']['userdata']['user_data']['pool']['startup'] == '1'
  default['cyclecloud']['cluster']['autoscale']['stop_enabled'] = node['ec2']['userdata']['user_data']['pool']['shutdown'] == '1'
  default['cyclecloud']['cluster']['autoscale']['start_callback'] = node['ec2']['userdata']['user_data']['pool']['autostartCallback']
  default['cyclecloud']['cluster']['autoscale']['stop_callback'] = node['ec2']['userdata']['user_data']['pool']['autostopCallback']

  # Condor pool passowrd, legacy stuff we need to move this something serious!
  default['htcondor']['pool_password'] = node['ec2']['userdata']['user_data']['pool']['key']

  # CycleServer admin password
  default['cycle_server']['admin']['pass'] = node['ec2']['userdata']['user_data']['pool']['adminPassword']
end

# Cluster user
if node['ec2']['userdata']['user_data']['user']
  default['cyclecloud']['cluster']['user']['name'] = node['ec2']['userdata']['user_data']['user']['name']
  default['cyclecloud']['cluster']['user']['uid'] = node['ec2']['userdata']['user_data']['user']['id']
  default['cyclecloud']['cluster']['user']['gid'] = node['ec2']['userdata']['user_data']['user']['groupId']
  default['cyclecloud']['cluster']['user']['description'] = node['ec2']['userdata']['user_data']['user']['description']
  default['cyclecloud']['cluster']['user']['password'] = node['ec2']['userdata']['user_data']['user']['password']
  default['cyclecloud']['cluster']['user']['public_key'] = nil
end

# Config webserver
if node['ec2']['userdata']['user_data']['config']
  default['cyclecloud']['config']['web_server'] = node['ec2']['userdata']['user_data']['config']['webServer']
end

# Example json
# {
#   "cyclecloud": {
#     "config": {
#       "web_server": "http://127.0.0.1:5186",
#       "username": "my user",
#       "password": "my password"
#     },
#     "amqp": {
#       "hostname": "127.0.0.1",
#       "port": 5168,
#       "username": "guest",
#       "password": "guest", # [SuppressMessage("Microsoft.Security", "CS001:SecretInline", Justification="example json")]
#       "vhost": "/"
#     },
#     "blackboard": {
#       "type": "s3 or cs",
#       "url": "s3://foo.bar.baz/blackboard",
#       "access_key": "AKIA",
#       "secret_key": "ZOIUSDF",
#       "default_region": "us-east-1",
#       "username": "only if CS backed search",
#       "password": "only if CS backed search"
#     },
#     "cluster": {
#       "name": "Test Cluster",
#       "id": "Test Cluster ID (same as name)",
#       "parent_id": null,
#       "user": {
#         "name": "cluster.user",
#         "uid": 5000,
#         "gid": 5000,
#         "description": "awesome user!",
#         "password": "super secret!"
#       },
#       "autoscale": {
#         "start_enabled": true,
#         "start_callback": "http://127.0.0.1:5186/autoscale/start",
#         "stop_enabled": true,
#         "stop_callback": "http://127.0.0.1:5186/autoscale/stop"
#       }
#     }
#   },
#   "cluster_init": {
#     "url": "s3://foo.bar.baz/cluster_init",
#     "access_key": "AKIA",
#     "secret_key": "SECRET",
#     "default_region": "us-east-1"
#   },
#   "htcondor": {
#     "pool_password": "my password"   // optional  now!
#   },
#   "cycle_server": {
#     "license": "LICENSE STRINGE GOES HERE",  // technically optional
#     "admin": {
#       "pass": "my password" // optional now!
#     }
#   }
# }
