import sys
import os.path
import shutil
import urllib.request, urllib.parse, urllib.error

# Works around the fact that hostname lookup on private names in VPC doesn't work.
#
# It creates a giant hosts file with mappings for X.Y.*.*
# if your ip address starts with X.Y. This assumes a /16 subnet for now.
# It also assumes that AWS names their names "ip-A-B-C-D" for an address of A.B.C.D.

domain = None
alt_domain = None
if len(sys.argv) > 1 and sys.argv[1].lstrip():
    alt_domain = sys.argv[1].lstrip().lstrip('.')
if len(sys.argv) > 2 and sys.argv[2].lstrip():
    domain = sys.argv[2].lstrip().lstrip('.')

# either we haven't run, or we got interrupted

ipaddr = urllib.request.urlopen("http://169.254.169.254/latest/meta-data/local-ipv4").read().decode()

if domain is None:
    local_fqdn = urllib.request.urlopen("http://169.254.169.254/latest/meta-data/hostname").read().decode()
    #local_hostname = local_fqdn.split('.')[0]
    domain = local_fqdn.split('.')[1:]
    domain = ".".join(domain)
    print("Found domain : %s" % (domain))
else:
    print("Overriding domain : %s" % (domain))

parts = ipaddr.split(".")

b4 = parts[0]
b3 = parts[1]

# make a backup (at this point /etc/hosts is clean because it's overwritten only in the last operation)
shutil.copyfile("/etc/hosts", "/etc/hosts.vpc.working")

# write to a temp file
f = open("/etc/hosts.vpc.working", "a")

f.write("\n#The following was autogenerated for VPC environments.\n")

for b2 in range(0, 256):
    # exclude 0 and 255 here
    for b1 in range(1, 255):
        ip = "%s.%s.%s.%s" % (b4, b3, b2, b1)
        hostname = "ip-%s-%s-%s-%s" % (b4, b3, b2, b1)
        fqdn = "%s.%s" % (hostname, domain)
        f.write("%s %s %s\n" % (ip, fqdn, hostname))
        if alt_domain:
            alt_fqdn = "%s.%s" % (hostname, alt_domain)
            f.write("%s %s %s\n" % (ip, alt_fqdn, hostname))

f.close()

# this indicates success
shutil.copyfile("/etc/hosts", "/etc/hosts.vpc")

# atomic move as the last operation
shutil.move("/etc/hosts.vpc.working", "/etc/hosts")
