#
# This is a report handler that on successful converge will remove the 'fast' crontab we install
# on every machine to run the initial converge.
#
# If maintenance converges are enabled, a slow maintenance cron job will be installed instead.
#
module CycleCloud
  class ConvergeHandler < Chef::Handler
    require 'fileutils'

    def create_keepalive
      keepalive_file = ::File.join(node[:cyclecloud][:home], 'system/run/keepalive')
      FileUtils.touch(keepalive_file) unless ::File.exist?(keepalive_file)
    end

    def report
      if run_status.run_context.reboot_requested?
        Chef::Log.info('Delay changing converge frequency, pending reboot.')
      else
        # put a file on the filesystem to save time of first successful converge
        create_keepalive
      end
    end
  end
end
