#
# Cookbook Name:: cyclecloud
# Recipe:: _update_dns
#
# Use nsupdate to force a dynamic DNS record update from the instance to the
# configured DNS server.
#
# Useful ONLY when allowed by DNS policy, and the cluster is using a DNS
# server that allows dynamic updates.
# For example, a VPC/VPN user may configure the cluster to use a local DNS server
# via the EC2 DHCPOptions page.
#
# Sample usage:
# [cluster sge]
#   [[node defaults]]
#     [[[configuration]]]
#     cyclecloud.update_dns.domain = mydomain.com
#   [[node master]]
#     [[[configuration]]]
#     cyclecloud.update_dns.nodename = mymaster
#
# Results in all nodes in mydomain.com, and master named mymaster.mydomain.com
#
# Copyright 2014, Cycle Computing
#
# All rights reserved - Do Not Redistribute
#

# TODO: Currently, it may be required to enable the cyclecloud.hosts "simple_vpn_dns" setting and
# TODO: generate the hosts file for the new domain as well.
# TODO: This requires more testing...  (Currently only tested with this setting turned on)
#
# TODO: CRON
# TODO: This currently relies on maintenance converge to re-publish the name at least every
# TODO: 24 hours.
# TODO: It should probably use a crontab instead of the final "execute" block
#
# TODO: WINDOWS
# TODO: We need to support windows hosts as well.  The page below describes at least one way:
# TODO: http://wiki.inisec.com/index.php/Nsupdate_for_windows
#
# TODO: SECURITY
# TODO: Some DNS servers are going to require a key file for auth.  We'll need to determine
# TODO: the right way for the user to provide the Key
#

domain_name = node[:cyclecloud][:dns][:domain]
custom_name = node[:cyclecloud][:dns][:alias]

ns_update_file = '/opt/cycle/jetpack/config/.ns_update'

# This recipe only applies if a custom domain has been set
if domain_name.nil?
  log 'No domain name provided for DNS update.  Skipping DNS update...' do
    level :warn
  end
  return
end

local_hostname = node[:cyclecloud][:instance][:hostname]
short_name = local_hostname.split('.')[0]

# Always register node with `hostname`.domain.com
fully_qualified_domain_name = "#{short_name}.#{domain_name}"

# Allow an optional alias (CNAME) for the node
domain_name_alias = if custom_name.nil?
                      nil
                    else
                      "#{custom_name}.#{domain_name}"
                    end

node_ip = node[:cyclecloud][:instance][:ipv4]
reverse_node_ip = node_ip.split('.').reverse.join('.')
reverse_node_ip_inaddr = "#{reverse_node_ip}.in-addr.arpa"

log "Updating DNS entry #{fully_qualified_domain_name}  (alias: #{domain_name_alias}) with ip #{node_ip} (reverse: #{reverse_node_ip})" do
  level :info
end

template ns_update_file do
  source 'ns_update.erb'
  owner 'root'
  group 'root'
  variables(fully_qualified_domain_name: fully_qualified_domain_name,
            domain_name_alias: domain_name_alias,
            node_ip: node_ip,
            reverse_node_ip: reverse_node_ip_inaddr)
end

execute 'performing DNS update' do
  command "nsupdate #{ns_update_file}"
  cwd '/tmp'
  user 'root'
end
