#
# Cookbook Name:: cyclecloud
# Recipe:: default
#
# Copyright 2014, CycleComputing LLC
#
# All rights reserved - Do Not Redistribute
#

# Set proxy before apt or yum get called
ENV['http_proxy'] = node['http_proxy']['url'] unless node['http_proxy']['url'].empty?

# Include our compatibility layer for new images to act like old ones
include_recipe 'cyclecloud::_first'
include_recipe 'cyclecloud::_starttime'
include_recipe 'cyclecloud::_passwd'

# Jetpack doesn't set it's permissions correctly and running jetpack commands as
# 'cyclecloud' user/group can cause permission errors. This is a bit of a hack to fix it
execute 'Set log permissions' do
  command "chmod 664 #{node['cyclecloud']['home']}/logs/*.log && chown cyclecloud:cyclecloud #{node['cyclecloud']['home']}/logs/*.log"
  only_if { node['os'] == 'linux' }
  only_if { ::File.exist?("#{node['cyclecloud']['home']}/logs/*.log")}
end

%w( system/chef/handlers system/run system/bin ).each do |d|
  directory ::File.join(node['cyclecloud']['home'], d) do
    recursive true
  end
end

include_recipe 'cyclecloud::_chef_handlers'
include_recipe 'cyclecloud::_thunderball'

if node['os'] == 'windows'

  # This is for backward compatibility w/ old cookbooks that reference old bootstrap location
  directory node['cyclecloud']['bootstrap'] do
    recursive true
  end

  env 'CYCLECLOUD_HOME' do
    value node['cyclecloud']['home']
  end
  env 'CYCLECLOUD_BOOTSTRAP' do
    value node['cyclecloud']['bootstrap']
  end

  env 'PATH' do
    delim ';'
    value "#{node['cyclecloud']['home']}\\bin"
    action :modify
  end

else
  
  directory node['cyclecloud']['bootstrap']

  file '/etc/profile.d/cyclecloud.sh' do
    content <<EOF
    CYCLECLOUD_HOME=#{node['cyclecloud']['home']}
    CYCLECLOUD_BOOTSTRAP=#{node['cyclecloud']['bootstrap']}
EOF
    mode 0755
    not_if { ::File.exist?('/etc/profile.d/cyclecloud.sh') }
  end

  # Include MOTD on linux
  #include_recipe 'cyclecloud::_motd'
  include_recipe 'cyclecloud::_converge_on_boot'
  #include_recipe 'cyclecloud::_selinux'
end


# dump node data to json file so available to external scripts
# deep merge here borrowed from
# http://api.rubyonrails.org/v2.3.10/classes/ActiveSupport/CoreExtensions/Hash/DeepMerge.html
ruby_block 'dump node.json' do
  block do
    require 'json'
    require 'fileutils'

    node_attrs = {}
    node.keys.each do |key|
      node_attrs[key] = if node[key].class == Chef::Node::Attribute
                          node[key].to_hash
                        else
                          node[key]
                        end
    end
    cycle_conf_dir = node['platform'] == 'windows' ? "#{node['cyclecloud']['home']}\\config" : "#{node['cyclecloud']['home']}/config"

    # for some reason 'run_list' is not in the list returned by node.keys
    node_attrs['run_list'] = node.run_list.to_a
    ::FileUtils.mkdir_p(cycle_conf_dir)
    filename = ::File.join(cycle_conf_dir, 'node.json')
    node_json = ::File.open(filename, 'w:utf-8')
    node_json.write(node_attrs.to_json)
    node_json.close
    ::FileUtils.chmod 0660, filename if node['os'] != 'windows'
    ::FileUtils.chown 'root', 'cyclecloud', filename if node['os'] != 'windows'
  end
end

# Create a directory for scheduled shutdowns to live in
directory "#{node['cyclecloud']['home']}/run/scheduled_shutdown" do
  recursive true
  rights :write, 'Everyone' if node['os'] == 'windows'
  rights :read, ['Administrators', 'SYSTEM'] if node['os'] == 'windows'
  mode 0770 if node['os'] == 'linux'
end

include_recipe 'cyclecloud::_discoverable' if node['cyclecloud']['discoverable']

# Put the scheduled_shutdown healtcheck script in place
cookbook_file "#{node['cyclecloud']['home']}/config/healthcheck.d/scheduled_shutdown.py" do
  mode 0770 if node['os'] == 'linux'
end

# Include cuser so that we can install SSH keys, but only do so if it hasn't already been included so
# that older runlists continue to work (order matters). Change the base home directory to /home since we can assume here
# that it's not using a shared filer (if it was it would have been included after cshared::client)
# NOTE: This is some legacy behavior we probably want to remedy
unless node.recipe? 'cuser' or node.recipe? 'cuser::default'
  node.default['cuser']['base_home_dir'] = '/home'
  include_recipe 'cuser::default'
end

# Legacy bootstrap access for older Slurm clusters
include_recipe 'cyclecloud::_bootstrap_access'
