require 'spec_helper'

describe 'cyclecloud::_bootstrap_access' do
    context 'For Slurm Cookbook metadata version <= 0.1.0 allow access' do
        cached(:chef_run) do
            ChefSpec::SoloRunner.new( :platform => 'centos', :version => '6.9')  do |node|
                node.default['cyclecloud']['home'] = '/opt/cycle/jetpack'
                node.default['cookbooks']['slurm']['version'] = '0.1.0'
    
            end.converge(described_recipe)    
        end
    
        it 'ensures jetpack dir has correct permissions' do
            cyclecloud_home = '/opt/cycle/jetpack'
            expect(chef_run).to create_directory("#{cyclecloud_home}").with(:mode => 02775)
            expect(chef_run).to create_directory("#{cyclecloud_home}/system/bootstrap").with(:mode => 02775)
        end
    end

    context 'For Slurm Cookbook metadata version > 0.1.0 ' do
        cached(:chef_run) do
            ChefSpec::SoloRunner.new( :platform => 'centos', :version => '6.9')  do |node|
                node.default['cyclecloud']['home'] = '/opt/cycle/jetpack'
                node.default['cookbooks']['slurm']['version'] = '0.1.1'
    
            end.converge(described_recipe)    
        end
    
        it 'do not change jetpack dir permissions' do
            cyclecloud_home = '/opt/cycle/jetpack'
            expect(chef_run).to_not create_directory("#{cyclecloud_home}")
            expect(chef_run).to_not create_directory("#{cyclecloud_home}/system/bootstrap")
        end
    end   

    context 'For non-Slurm clusters ' do
        cached(:chef_run) do
            ChefSpec::SoloRunner.new( :platform => 'centos', :version => '6.9')  do |node|
                node.default['cyclecloud']['home'] = '/opt/cycle/jetpack'
                node.default['cookbooks']['slurm'] = nil
    
            end.converge(described_recipe)    
        end
    
        it 'do not change jetpack dir permissions' do
            cyclecloud_home = '/opt/cycle/jetpack'
            expect(chef_run).to_not create_directory("#{cyclecloud_home}")
            expect(chef_run).to_not create_directory("#{cyclecloud_home}/system/bootstrap")
        end
    end       
end
