require 'spec_helper'

shared_examples 'converge on boot' do |platform, version|
  context "converge on boot enabled" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: platform, version: version) do |node|
        node.override['cyclecloud']['converge_on_boot'] = true
      end.converge('cyclecloud::_converge_on_boot')
    end

    it 'does not disable converge on boot' do
      expect(chef_run).to_not delete_cron('cyclecloud-bootstrap')
    end
  end
  context "converge on boot disabled" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: platform, version: version)
      .converge('cyclecloud::_converge_on_boot')
    end

    it 'disables converge on boot' do
      expect(chef_run).to delete_cron('cyclecloud-bootstrap')
    end
  end
end

describe 'cyclecloud::_converge_on_boot' do
  platforms = {
    'centos' => ['7.4.1708'],
    'ubuntu' => ['16.04'],
  }

  platforms.each do |platform, versions|
    versions.each do |version|
      it_behaves_like 'converge on boot', platform, version
    end
  end
end
