require 'spec_helper'
require 'json'
require 'chef'

describe 'CycleCloudCluster' do
  describe '#fetch_discoverable_cs' do
    cached(:nodes) do
      nodes_json = File.join(File.expand_path(File.dirname(__FILE__)), 'data', 'nodes.json')
      JSON.parse(File.read(nodes_json)).map {|n| Chef::Node.from_hash(n)}
    end


    cached(:cluster) { CycleCloudCluster.new(Mash.new({cyclecloud:
                                                      {cluster:
                                                         {id: 'condor-azure'}}})) }

    before do
      Chef::Config[:solo] = true
      allow(cluster).to receive(:fetch_discoverable).and_return(nodes)
    end

    it 'finds all nodes in the cluster' do
      expect(cluster.search({:clusterUID => 'condor-azure'}).length).to be(3)
    end

    it 'finds only the condor_master using role' do
      results = cluster.search({:clusterUID => 'condor-azure', :role => 'condor_unified_manager_cs40'})
      expect(results.length).to be(1)
    end

    it 'finds only the condor_master using recipe' do
      results = cluster.search({:clusterUID => 'condor-azure', :recipe => 'ccondor::cm'})
      expect(results.length).to be(1)
    end

    it 'finds only the condor_master using recipe and role' do
      results = cluster.search({:clusterUID => 'condor-azure',
                                :recipe => 'ccondor::cm',
                                :role => 'condor_unified_manager_cs40'})
      expect(results.length).to be(1)
    end

    it 'finds no results when using a valid role but invalide recipe' do
      results = cluster.search({:retries => 0,
                                :clusterUID => 'condor-azure',
                                :recipe => 'doesnotexist',
                                :role => 'condor_unified_manager_cs40'})
      expect(results.length).to be(0)
    end

    it 'finds 3 results for recipe => cyclecloud' do
      results = cluster.search({:clusterUID => 'condor-azure',
                                :recipe => 'cyclecloud'})
      expect(results.length).to be(3)
    end

    it 'raises error when more than one result found and :singular flag set' do
      query = {:retries => 0,
               :clusterUID => 'condor-azure',
               :recipe => 'cyclecloud',
               :singular => true}
      expect{cluster.search(query)}.to raise_error(SearchException)
    end

    it 'raises error when no results are found' do
      query = {:retries => 0,
               :clusterUID => 'condor-azure',
               :recipe => 'doesnotexist',
               :singular => true}
      expect{cluster.search(query)}.to raise_error(SearchException)
    end

    it 'filters the results by the passed block' do
      results = cluster.search({:clusterUID => 'condor-azure'}){|n| n.name == 'master'}
      expect(results.length).to be(1)
    end
  end
end
