require 'spec_helper'

shared_examples 'default attributes' do |platform, version|
  context "On #{platform} #{version}" do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: platform, version: version) do |node|
        node.override['cyclecloud']['image']['custom'] = false
      end.converge(described_recipe)
    end

    before do
      getenforce_double = double('getenforce_double')
      allow(getenforce_double).to receive(:run_command)
      allow(getenforce_double).to receive(:stdout).and_return("enforcing")

      yum_double = double('yum_double')
      allow(yum_double).to receive(:run_command)
      allow(yum_double).to receive(:exitstatus).and_return(0)

      allow(File).to receive(:exist?).with(anything).and_call_original
      allow(File).to receive(:exist?).with('/etc/profile.d/cyclecloud.sh').and_return(false)

      allow(::File).to receive(:exist?).with('/sys/fs/selinux/enforce').and_return(true)
      allow(::File).to receive(:read).and_call_original
      allow(::File).to receive(:read).with('/sys/fs/selinux/enforce').and_return(1)

      stub_command(/grep "#The following was autogenerated for Cloud environments.*" \/etc\/hosts/).and_return(false)
      stub_command('which sudo').and_return('/usr/bin/sudo')

      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).and_call_original
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('cuser::default')
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('cyclecloud::_yum_cache')
    end

    %w(
      cyclecloud::_first
      cyclecloud::_starttime
      cyclecloud::_passwd
      cyclecloud::_converge_on_boot
      cyclecloud::_chef_handlers
      cyclecloud::_thunderball
      cyclecloud::_bootstrap_access
    ).each do |recipe|
      it "includes #{recipe}" do
        expect(chef_run).to include_recipe(recipe)
      end
    end

    it 'Does not include cyclecloud::_discoverable' do
      expect(chef_run).to_not include_recipe('cyclecloud::_discoverable')
    end

    %w(
      /opt/cycle/jetpack/system/chef/handlers
      /opt/cycle/jetpack/system/run
      /opt/cycle/jetpack/system/bin
      /opt/cycle/jetpack/system/bootstrap
      /opt/cycle/jetpack/run/scheduled_shutdown
    ).each do |directory|
      it "creates #{directory}" do
        expect(chef_run).to create_directory(directory)
      end
    end

    %w(
      /etc/profile.d/cyclecloud.sh
      /opt/cycle/jetpack/config/healthcheck.d/scheduled_shutdown.py
    ).each do |file|
      it "renders file #{file}" do
        expect(chef_run).to render_file(file)
      end
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end
end

describe 'cyclecloud::default' do
  platforms = {
    'centos' => ['6.8', '7.4.1708'],
    'ubuntu' => ['14.04', '16.04'],
  }

  platforms.each do |platform, versions|
    versions.each do |version|
      it_behaves_like 'default attributes', platform, version
    end
  end
end
