require 'spec_helper'

shared_examples "_first on Generic Linux" do |platform, version|
  context "On #{platform} #{version}" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version).converge(described_recipe)
    end

    before do
      stub_command('which sudo').and_return('/usr/bin/sudo')
      stub_command('grep "#The following was autogenerated for Cloud environments." /etc/hosts').and_return(true)
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).and_call_original
      allow_any_instance_of(Chef::Recipe).to receive(:include_recipe).with('cyclecloud::_yum_cache')
    end

    %w(
      cyclecloud::_limits
      cyclecloud::_hosts
      cvolume
      cshared
    ).each do |recipe|
      it "includes #{recipe}" do
        expect(chef_run).to include_recipe(recipe)
      end
    end

    %w(
      /opt/cycle/jetpack/config/chefstate
      /mnt/scratch
    ).each do |directory|
      it "creates #{directory}" do
        expect(chef_run).to create_directory(directory)
      end
    end

    it 'deletes /etc/cron.daily/mlocate.cron' do
      skip '@deprecated in 8.0'
      expect(chef_run).to delete_file('/etc/cron.daily/mlocate.cron')
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end
end

describe 'cyclecloud::_first' do
  platforms = {
    'centos' => ['6.9', '7.4.1708'],
    'ubuntu' => ['14.04', '16.04'],
  }

  platforms.each do |platform, versions|
    versions.each do |version|
      it_behaves_like '_first on Generic Linux', platform, version
    end
  end
end
