require 'spec_helper'

describe 'cyclecloud::_instance' do
  context 'Azure Setup (InstanceID Specified)' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '6.9') do |node|
        node.automatic['cyclecloud']['instance']['provider'] = 'azure'
        node.automatic['cyclecloud']['instance']['id'] = 'test-azure-instance'
        node.automatic['ipaddress'] = '10.0.0.10'
        node.automatic['hostname'] = 'MyCycleVM'
      end.converge('cyclecloud::_instance')
    end

    it 'sets the instance attributes for azure' do
      expect(chef_run.node['cyclecloud']['instance']['provider']).to eq('azure')
      expect(chef_run.node['cyclecloud']['instance']['id']).to eq('test-azure-instance')
      expect(chef_run.node['cyclecloud']['instance']['ipv4']).to eq('10.0.0.10')
      # expect(chef_run.node['cyclecloud']['instance']['hostname']).to eq('ip-0A00000A.local')
      expect(chef_run.node['cyclecloud']['instance']['public_hostname']).to eq(nil)
      expect(chef_run.node['cyclecloud']['instance']['public_ipv4']).to eq(nil)
      expect(chef_run.node['cyclecloud']['instance']['region']).to eq(nil)
      expect(chef_run.node['cyclecloud']['instance']['zone']).to eq(nil)
      expect(chef_run.node['cyclecloud']['instance']['type']).to eq(nil)
    end
  end

  # TODO: context read from file
  context 'Azure Setup (InstanceID from jetpack.ini)' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '6.9') do |node|
        node.automatic['cyclecloud']['instance']['provider'] = 'azure'
        # node.automatic['cyclecloud']['instance']['cloud_service'] = 'myService'
      end.converge('cyclecloud::_instance')
    end
    before :each do
      allow(::File).to receive(:exist?).and_return(true)
      allow(::File).to receive(:readlines).and_return(['a', 'instance_id=myService-MyRole_IN_1', 'c'])
    end
    it 'generates an instance id for PaaS' do
      expect(chef_run.node['cyclecloud']['instance']['provider']).to eq('azure')
      expect(chef_run.node['cyclecloud']['instance']['id']).to eq('myService-MyRole_IN_1')
    end
  end
end
