require 'spec_helper'

describe 'cyclecloud::_limits' do
  context '_limits on Generic Linux' do
    cached(:chef_run) do
      ChefSpec::SoloRunner.new(platform: 'centos', version: '7.4.1708') do |node|
        # modify the built in default limit
        node.override['cyclecloud']['security']['limits']['*']['soft']['nofile'] = 500000

        # set a custom limit for ec2-user number of procs
        node.override['cyclecloud']['security']['limits']['cyclecloud']['soft']['nproc'] = 1234
      end.converge(described_recipe)
    end

    it 'creates directory' do
      expect(chef_run).to create_directory('/etc/security/limits.d')
    end

    it 'renders the limits file' do
      # 1 defaults
      expect(chef_run).to render_file('/etc/security/limits.d/cyclecloud.conf').with_content('* hard nofile 1048576')

      # 1 default with overwritten value
      expect(chef_run).to render_file('/etc/security/limits.d/cyclecloud.conf').with_content('* soft nofile 500000')

      # 1 custon
      expect(chef_run).to render_file('/etc/security/limits.d/cyclecloud.conf').with_content('cyclecloud soft nproc 1234')
    end
  end
end
