require 'spec_helper'

shared_examples '_starttime on Generic Linux' do |exists|
  context "with File.exist?(starttime_file) = #{exists}" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: 'centos', version: '7.4.1708') do |node|
        node.default['cyclecloud']['instance']['id'] = 'foobar'
      end.converge(described_recipe)
    end

    before do
      allow(::File).to receive(:exist?).and_call_original
      allow(::File).to receive(:exist?).with('/opt/cycle/jetpack/config/startTime.txt').and_return(exists)
      allow(::File).to receive(:exist?).with('/proc/uptime').and_return(true)
      allow(::IO).to receive(:readlines).and_call_original
      allow(::IO).to receive(:readlines).with('/opt/cycle/jetpack/config/startTime.txt').and_return("12345678\nfoobar") if exists
      allow(::IO).to receive(:read).and_call_original
      allow(::IO).to receive(:read).with('/proc/uptime').and_return('1964176.97 14881678.39')
    end

    # The file already exists in the true case
    unless exists
      it 'renders starttime file' do
        expect(chef_run).to render_file('/opt/cycle/jetpack/config/startTime.txt')
          .with_content(/\d+\nfoobar/)
      end
    end

    it 'converges successfully' do
      expect { chef_run }.to_not raise_error
    end
  end
end

describe 'cyclecloud::_starttime' do
  [true, false].each do |bool|
    it_behaves_like '_starttime on Generic Linux', bool
  end
end
