#
# Cookbook Name:: jetpack
#
# Copyright 2015, Cycle Computing LLC
#
# All rights reserved - Do Not Redistribute
#

# Usage: jetpack send [OPTIONS]

#   Sends a message to CycleCloud

# Options:
#   -m, --message TEXT      The message to send
#   -f, --file PATH         The file to send.
#   -r, --routing-key TEXT  The amqp routing-key associated with the message
#   --help                  Show this message and exit.

action :send do

  routing_key = "-r #{new_resource.routing_key}"

  # Send message via content parameter.
  if !new_resource.content.nil?

    # Store block msg to file to avoid escaping issues
    f = Tempfile.new('sendmsg')
    begin
      Chef::Log.debug "Sending: #{new_resource.content} to #{f.path}"
      
      f.write(new_resource.content)
      f.size
      f.close

      # TODO: should probably create and remove the file using file resource
      execute "#{node['cyclecloud']['jetpack']['executable']} send #{routing_key} -f #{f.path} && rm -f #{f.path}"
      new_resource.updated_by_last_action(true)
    ensure
      f.close
    end
  # Send message via filename.
  elsif !new_resource.file.nil?
    execute "#{node['cyclecloud']['jetpack']['executable']} send #{routing_key} -f '#{new_resource.file}'"
    new_resource.updated_by_last_action(true)
  # Resource name is the message, send that.
  else
    escaped_name = Regexp.escape(new_resource.name)
    
    execute "#{node['cyclecloud']['jetpack']['executable']} send #{routing_key} -m '#{escaped_name}'"
    new_resource.updated_by_last_action(true)
  end
    
    

end
