require 'spec_helper'

describe 'jetpack::test' do
  cached(:chef_run) do
      ChefSpec::SoloRunner.new(:platform => 'centos', :version => '6.8') do |node|
        node.default['cyclecloud']['home'] = '/opt/cycle/jetpack'

      end.converge(described_recipe)    
  end

  # This is an empty recipe, and does not need to happen to
  # include a LWRP
  it 'not include recipe jetpack::default' do
    expect(chef_run).to_not include_recipe('jetpack::default')
  end

  it 'logs a test message with warn level' do
    expect(chef_run).to log_jetpack_log('This is a message from JetPack Test!').with(level: "warn")
  end

  it 'sends a simple test message to benchmark.results' do
    expect(chef_run).to send_jetpack_send('jetpack send simple message from jetpack test').with(routing_key: "benchmark.results")
  end
  

  it 'sends a more complex test message to benchmark.results' do
    message = <<-EOH
    { 'msg': 'jetpack send from jetpack test',
      'foo': 'bar' }
    EOH
    expect(chef_run).to send_jetpack_send('Jetpack Send block test').with(content: message,
                                                                          routing_key: "benchmark.results")
  end

    
  
end
