import os
import subprocess
import sys
import socket
import logging
import traceback

LOCAL_JOB_ID_KEY = "cycleTandemLocalJobId"
LOCAL_SUBJOB_ID_KEY = "cycleTandemLocalJobSubId"
LOCAL_SUBMISSION_ID_KEY = "cycleTandemLocalSubmissionId"
JOB_STATE = "cycleTandemJobState"
SCHED_NAME_KEY = "cycleTandemSchedulerName"
CYCLE_JOB_STATES = {"i": "idle",
                    "h": "held",
                    "r": "running",
                    "e": "system_error",
                    "c": "complete",
                    "x": "removed"
                    }


true_subprocess = subprocess


def set_subprocess(mock_subprocess):
    global subprocess
    subprocess = mock_subprocess
    

def restore_subprocess():
    global subprocess
    subprocess = true_subprocess


def default_logger():
    logging.basicConfig(stream=sys.stderr)
    return logging.getLogger()


def hostname():
    hostname, _, code = call(["hostname"])
    if code == 0:
        return hostname.strip()
    return socket.gethostname()


def call(cmd, stdin=None):
    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, stdin=subprocess.PIPE)
    if stdin:
        proc.stdin.write(stdin)
    out, err = proc.communicate(stdin)
    return out, err, proc.returncode


def check_call(cmd, stdin=None):
    out, err, return_code = call(cmd, stdin)
    if return_code != 0:
        cmd_str = cmd if type(cmd) is str else " ".join(cmd)
        print("Command failed = %s " % cmd_str, file=sys.stderr) 
        print(err, file=sys.stderr)
        sys.exit(return_code)
    return out


def _try_read(path):
    try:
        if not os.path.exists(path):
            return ""
        
        with open(path) as fr:
            return fr.read()
    except:
        traceback.print_exc(file=sys.stderr)
        return ""


def make_std_logs(stdout_path, stderr_path):
    ret = {}
    ret.update(make_log("StdOut", stdout_path))
    ret.update(make_log("StdErr", stderr_path))
    return ret

 
def make_log(name, path):
    return {name: {"Path": path, "Contents": _try_read(path)}}


def error_and_exit(stderr):
    print(stderr, file=sys.stderr)
    sys.exit(1)
