def regionalize_url(url, node)
  if url =~ %r{\As3://} and url =~ %r{\[:region:\]}

    # If we are using aws as a provider, use the region the instance is in
    if node[:cyclecloud][:instance][:provider] == "ec2"
      region = node[:cyclecloud][:instance][:region] || "us-east-1"
    else  # otherwise, we are using a different provider but still using s3 so just use us-east-1
      region = "us-east-1"
    end
    url.sub!(%r{\[:region:\]}, region)
    url
  else
    url
  end
end

def homedir(user, node)
  if node[:os] == 'windows'
    "C:\\Users\\#{user}"
  else
    Dir.home(user)
  end
end

def username_or_password_empty?(username, password)
  username.empty? or password.empty?
end

use_inline_resources

action :create do

  username_or_password_empty = username_or_password_empty?(new_resource.username, new_resource.password)
  is_azure = !new_resource.type.nil? and new_resource.type == "az"
  # fail if not using instance creds and the username/password or empty


  if !is_azure && !new_resource.use_instance_creds && username_or_password_empty
    raise "You must specify either `use_instance_creds true` or a username and password for a thunderball_config"
  end

  if !is_azure && new_resource.use_instance_creds && !username_or_password_empty
    raise "You cannot specify both `use_instance_creds true` and a username and password for a thunderball_config"
  end

  node = ::Thunderball::NodeAccessor.node

  config_location = "/opt/cycle/jetpack/config/thunderball-#{new_resource.name}.ini"
  config_location = "C:\\cycle\\jetpack\\config\\thunderball-#{new_resource.name}.ini" if node[:os] == "windows"

  directory ::File.dirname(config_location) do
    recursive true
  end

  # resolve username/access_key
  if is_azure
    access_key = new_resource.access_key
  else
    access_key = new_resource.username
  end

  template config_location do
    source "thunderball.ini.erb"
    cookbook "thunderball"
    variables(
      :name => new_resource.name,
      :use_instance_creds => new_resource.use_instance_creds,
      :access_key => access_key,
      :secret_key => new_resource.password,
      :endpoint => new_resource.endpoint,
      :default_region => new_resource.default_region,
      :proxy => new_resource.proxy_host,
      :proxy_port => new_resource.proxy_port,
      :matches => regionalize_url(new_resource.base, node),
      :type => new_resource.type,
      :sas_token => new_resource.sas_token,
      

      :report_metrics => node['cyclecloud']['pogo']['report_metrics'],
      :amqp_username => node['cyclecloud']['amqp']['username'],
      :amqp_password => node['cyclecloud']['amqp']['password'],
      :amqp_hostname => node['cyclecloud']['amqp']['hostname'],
      :amqp_port => node['cyclecloud']['amqp']['port'],
      :amqp_vhost => node['cyclecloud']['amqp']['vhost']
    )
    if node[:os] == "linux"
      mode '0660'
    end
  end
  node.override[:thunderball][:config][new_resource.name.to_sym] = {
    :filename => config_location,
    :base => regionalize_url(new_resource.base, node)
  }

end
