def regionalize_url(url)
  if url =~ %r{\As3://} and url =~ %r{\[:region:\]}
    region = node[:cyclecloud][:instance][:region]
    url.sub!(%r{\[:region:\]}, region)
    url
  else
    url
  end
end

def join_url(base, rest)
  [base.sub(%r{/+\z},''), rest.sub(%r{\A/+},'')].join('/')
end

def compose_url(new_resource, node)
  if new_resource.config
    base_url = node[:thunderball][:config][new_resource.config.to_sym][:base]
  elsif node[:thunderball][:config][:default][:base]
    base_url = node[:thunderball][:config][:default][:base]
  else
    base_url = node[:thunderball][:base]
  end
  join_url(base_url, new_resource.url)
end

def find_file_and_path(url)
  url =~ %r{\A(s3://|gs://|az://)[^/]+/(.+/)?([^/]+)\z}
  path = $2.nil? ? "" : $2
  filename = $3
  [path, filename]
end

action :get do
  Chef::Log.warn "The thunderball resource is deprecated and will be removed in the future. Use jetpack_download instead."

  node = ::Thunderball::NodeAccessor.node

  new_resource.storedir ||= node[:thunderball][:storedir]
  unless new_resource.url =~ %r{\A(s3://|gs://)[^/]+/(.+)/(.+)\z}
    url = compose_url(new_resource, node)
  else
    url = new_resource.url
  end

  url = regionalize_url(url)

  if new_resource.dest_file
    storedir = ::File.dirname(new_resource.dest_file)
    file_path = new_resource.dest_file
    file_part_path = file_path + '.part'
  else
    path, filename = find_file_and_path(url)
    storedir = ::File.join(new_resource.storedir, path)

    # If we care about only saving the filename (not the whole path)
    # i.e. resource is at cycle/foo/bar/baz/file.tgz and we just want to save it as "file.tgz" 
    # not the entire cycle/foo/bar/baz/file.tgz path
    if new_resource.file_only
      storedir = new_resource.storedir      
    end
    file_path = ::File.join(storedir, filename)
    file_part_path = file_path + '.part'
  end

  cmd = []
  cmd << new_resource.client.to_s
  if new_resource.config
    cmd << "--config=#{node[:thunderball][:config][new_resource.config.to_sym][:filename]}"
  else
    cmd << "--config=#{node[:thunderball][:config][:default][:filename]}"
  end

  cmd << 'get'

  cmd << url
  cmd << "\"#{file_part_path}\""

  directory file_path do
    path storedir
    recursive true
  end

  unless new_resource.username.empty? or new_resource.password.empty?
    cmd << ["--user #{new_resource.user}", "--password #{new_resource.password}"]
  end

  ruby_block "double check thunderball didn't fail for #{file_path}" do
    block do
      if ::File.size(file_part_path) == 0
        Chef::Application.fatal!("thunderball failed to download")
      else
        ::File.rename(file_part_path, file_path)
      end
    end
    action :nothing
  end

  execute "download tarball #{new_resource.name}" do
    if ::File.exist?(file_part_path)
      Chef::Log.info "#{file_part_path} exist. Assuming this is an error and using --force to try again."
      cmd << "--force"
    end
    command cmd.join(' ')
    notifies :create, "ruby_block[double check thunderball didn't fail for #{file_path}]", :immediately
    not_if do
      if ::File.exist?(file_path) and !new_resource.checksum.nil?
        require 'digest'
        Digest::SHA256.file(file_path).hexdigest == new_resource.checksum
      elsif ::File.exist?(file_path) and ::File.size(file_path) != 0
        true
      else
        false
      end
    end
  end

end
